// **************************************************************************************************************************
// 	boot-oct2224.gs
//	---------------
//		This script starts the DHCP and TFTP server required to boot the T51 OCTVOC2224 modules
//
//
// **************************************************************************************************************************

try
{	

    var len = argc;
    var g_hostIp= argv[0];
    var g_poolIp = argv[1];
    var g_poolIpCount = argv[2];
    var g_tftpRoot = argv[3];

							
	var fStat=system.file.stat("name="+g_tftpRoot+"/octvocmgw_master.img");
	if( fStat.exist == false )
	{
		var pwd = system.directory.get().name
		
		var strErr = "The file : "+g_tftpRoot+"/octvocmgw_master.img does not exist.";
		strErr += "The directory '" + pwd + "' should point to the location of octvocmgw_master.img";
		throw( new Error(strErr) );
		
	}

	fStat=system.file.stat("name="+g_tftpRoot+"/octvocmgw_slave.img");
	if( fStat.exist == false )
	{
		var pwd = system.directory.get().name
		
		var strErr = "The file : "+g_tftpRoot+"/octvocmgw_slave.img does not exist.";
		strErr += "The directory '" + pwd + "' should point to the location of octvocmgw_slave.img";
		throw( new Error(strErr) );
		
	}
       

    print( "Initializing DHCP Server...\n" );

	// Init DHCP services, allow to add remotes
	dhcp.init()
	
	// Start DHCP service with a specific host address
	dhcp.start("IpAddress=" + g_hostIp, "Dhcp.poolIpAddress=" + g_poolIp, "Dhcp.poolIpCount="+g_poolIpCount, "Tftp.transferRootPath=" + g_tftpRoot )
	
	print( "DHCP Server Started...\n" );

    print( "Initializing Modules hardware reset...\n" );
	//initiate hardware reset on the modules here....
	waitCount=0
	p = system.process.open("application=XXX_INSTDIR_XXX/bin/sngtc_tool show=false arguments.0.param=-dev arguments.1.param=sngdsp0 arguments.2.param=-hw-reset-modules")
	while ( p.info().status != "TERMINATED_WITH_DATA" && waitCount<100) {
	   system.sleep("timeout=100")	// wait 100 ms
       waitCount++;
	}
	
	r=p.read();
	if( r.success==true )
	{ 
	 print( "hw-reset-modules output: " +  r.data + "\n" )
	}
	p.close();

    print( "Modules Resetted...\n" );

    // Wait for remote to appear in the list.
	waitCount=0
	var deviceCount=0
	var maxDevice=dhcp.info().Dhcp.poolIpCount
	//allow 30 seconds for everyone to boot successfully.
	while( deviceCount < maxDevice && waitCount < 600)
	{
		if( dhcp.remote[deviceCount] != undefined )
		{
	        print( "Serving Device number " + deviceCount + "\n" )

			//if( deviceCount == 0 )
			   dhcp.remote[deviceCount].transfer.send("localFilename=octvocmgw_master.img")
			//else 
			  //dhcp.remote[deviceCount].transfer.send("localFilename=octvocmgw_slave.img")
			  
			deviceCount++
		}
		waitCount++;
		system.sleep("timeout=50")	// wait 50 ms
	}
	
	print("Served " + deviceCount + " devices within " + (waitCount * 50) + " milliseconds\n")
	maxDevice = deviceCount
    // Now wait for boot status ok.
	waitCount=0
	deviceCount=0
	while( deviceCount < maxDevice  )
	{
		// Wait for boot status ok
		var bs = dhcp.remote[deviceCount].status().BootStatus;

        print( "Device number " + deviceCount + " boot status is " + bs.errorCode + "\n" )
		
		if( bs.bootStatusCount && (bs.errorCode == "OK" ) )
			deviceCount++

		waitCount++;
		if( waitCount > 200)	 // allow 10 sec to boot and send all files
		{
			print( "remot= " + dhcp.remote[deviceCount] + "\n" )
			throw( new Error("Expecting boot status OK from devices\n") );
		}
		
		system.sleep("timeout=50")	// wait 50 ms
	}
	
	system.sleep("timeout=100")
	dhcp.terminate() 
}
catch(e)
{
	// Terminate the DHCP/TFTP server if an error occured
    try{ 
     dhcp.terminate()
	 
    } catch(ee){}
   
   print(e+"\n")
}
