#!/usr/bin/env python

"""

File:    resizeImage.py
Author:  Alkassoum Ahmoud <aahmoud@sangoma.com>
Date:    07/22/2013 12:04:58 AM
 
Description: Rezize an image file
 
Copyright (C) 2003-2011 Sangoma Technologies. 
All Rights Reserved.

This code is Sangoma Technologies Confidential Property.
Use of and Access to this code is covered by a previously executed
Non-disclosure Agreement between Sangoma Technologies and the Recipient.
This code is being supplied for evaluation purposes only and is not to be
used for any other purpose.  

"""


#Include this directory to  python sys.path

import sys
import os
from PIL import Image
from optparse import OptionParser

def main():

  #Parse the options
  usage = "usage: %prog [options] --file FILE_PATH... --width WIDTH... --height HEIGHT..."
  optParser = OptionParser(usage=usage)
  
  optParser.add_option('-F', '--file', action='store', type='string',
                       dest='file', metavar='FILE',
                       help="Input file path.")

  optParser.add_option('-W', '--width', type='int',help="Desired output width.")
  optParser.add_option('-H', '--height',type='int',help="Desired output height.")
  (options, args) = optParser.parse_args()

  #At least one repo and one branch must be defined, else the script has nothing
  #to do...
  if options.file is None:
    print("Error: At least an input file must be supplied.")
    sys.exit(1)

 ## if options.width is None:
##    print("Error: Output width must be specified.")
##    sys.exit(1)

##  if options.height is None:
##    print("Error: Output height must be specified.")
##    sys.exit(1)

  if options.width is None and options.height is None:

    out_image = None
    img_org = Image.open(options.file)
    # get the size of the original image
    width_org, height_org = img_org.size
    for x in range(0,3):
      if x == 0:
        dest_width = 176
        dest_height = 144
      elif x == 1:
        dest_width = 352
        dest_height = 288
      elif x == 2:
        dest_width = 640
        dest_height = 480
        
      if(width_org * height_org != dest_width*dest_height):
        out_image = img_org.resize((dest_width, dest_height), Image.ANTIALIAS)
      else:
        #same image size, nothing to do.
        out_image = img_org

      if len(out_image.split()) == 4:
        r, g, b, a = out_image.split()
        out_image = Image.merge("RGB", (r, g, b))
      elif len(out_image.split()) == 3:
        r, g, b = out_image.split()
        out_image = Image.merge("RGB", (r, g, b))
        
        
      # split image filename into name and extension
      name, ext = os.path.splitext(options.file)
      out_image_file = "%s_%s_%s%s" % (name, str(dest_width),str(dest_height), '.bmp')
      out_image.save(out_image_file,"BMP")
      print("resized file saved as %s" % out_image_file)
    
  else:

    if options.width is None:
      print("Error: Output width must be specified.")
      sys.exit(1)

    if options.height is None:
      print("Error: Output height must be specified.")
      sys.exit(1)

    out_image = None
    img_org = Image.open(options.file)
    # get the size of the original image
    width_org, height_org = img_org.size
    if(width_org * height_org != options.width*options.height):
      out_image = img_org.resize((options.width, options.height), Image.ANTIALIAS)
    else:
     #same image size, nothing to do.
     out_image = img_org
    # split image filename into name and extension
    name, ext = os.path.splitext(options.file)
    out_image_file = "%s_%s_%s%s" % (name, str(options.width),str(options.height), '.bmp')
    out_image.save(out_image_file,"BMP")
    print("resized file saved as %s" % out_image_file)


  sys.exit(0)


if __name__ == '__main__':
  main()
