#!/bin/sh
#
# This script is ran on video_mcu appliance startup to boot oct2224 
# modules using an embeded dhcp and tftp server
function valid_ip()
{
    local  ip=$1
    local  stat=1

    if [[ $ip =~ ^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}$ ]]; then
        OIFS=$IFS
        IFS='.'
        ip=($ip)
        IFS=$OIFS
        [[ ${ip[0]} -le 255 && ${ip[1]} -le 255 \
            && ${ip[2]} -le 255 && ${ip[3]} -le 255 ]]
        stat=$?
    fi
    return $stat
}


/sbin/ldconfig XXX_INSTDIR_XXX/lib

eth_if=sngdsp0
dhcp_ip_pool_size=3
generate_ip=0

ifup eth0

ifconfig sngdsp0 up

#retrieve the ip address of the host
host_ip=$(ifconfig $eth_if | grep 'inet addr:' | cut -d: -f2 | awk '{ print $1}')
echo $host_ip

#shutdown eth0
#ifdown eth0

#disable external ports
echo "Disabling External Ports..."
XXX_INSTDIR_XXX/bin/sngtc_tool -dev sngdsp0 -disable-ext-ports

echo "Waiting 1 second to be sure external ports are disabled..."
sleep 1

echo "Validating host ip address..."

if valid_ip $host_ip; then
  generate_ip=0
else
  generate_ip=1
  ifconfig sngdsp0 10.10.50.55 netmask 255.255.255.0 up
  host_ip=$(ifconfig $eth_if | grep 'inet addr:' | cut -d: -f2 | awk '{ print $1}')
  echo $host_ip
fi


eval $(echo "$host_ip" | awk '{print "IP1="$1";IP2="$2";IP3="$3";IP4="$4}' FS=.)
IP4=$(($IP4+2))
dhcp_ip_pool_base="$IP1.$IP2.$IP3.$IP4"
dhcp_ip_pool_base=$( printf $dhcp_ip_pool_base)
echo $dhcp_ip_pool_base



#launch the dhcp/tftp boot servers and waith for boot completion status
echo "Running dhcp/tftp boot mechanism..."
XXX_INSTDIR_XXX/bin/octconsole -q -r XXX_INSTDIR_XXX/scripts/boot-oct2224.gs $host_ip $dhcp_ip_pool_base $dhcp_ip_pool_size XXX_INSTDIR_XXX/scripts/boot_images/

#bring up eth0
#ifup eth0

if [ $generate_ip == 1 ]; then
  echo "Restoring sngdsp0 initial config"
  ifdown sngdsp0
  ifup sngdsp0
fi


#re-enable external ports
echo "Re-enabling External Ports..."
XXX_INSTDIR_XXX/bin/sngtc_tool -dev sngdsp0 -enable-ext-ports
echo "Waiting 1 second to be sure external ports are enabled..."
sleep 1
echo "Exiting boot script..."
